
# HG changeset patch
# User Maxim Dounin <mdounin@mdounin.ru>
# Date 1716502589 -10800
# Node ID 3b5594157fab8ce6c65872b136aa9c599bc005b8
# Parent  796fbd13ae3662f808365ad8cf5410b53f7dce68
Documented max_headers directive.

diff -r 796fbd13ae36 -r 3b5594157fab xml/en/docs/http/ngx_http_core_module.xml
--- a/xml/en/docs/http/ngx_http_core_module.xml	Tue May 14 17:59:30 2024 +0300
+++ b/xml/en/docs/http/ngx_http_core_module.xml	Fri May 24 01:16:29 2024 +0300
@@ -10,7 +10,7 @@
 <module name="Module ngx_http_core_module"
         link="/en/docs/http/ngx_http_core_module.html"
         lang="en"
-        rev="107">
+        rev="108">
 
 <section id="directives" name="Directives">
 
@@ -1778,6 +1778,31 @@
 </directive>
 
 
+<directive name="max_headers">
+<syntax><value>number</value></syntax>
+<default>1000</default>
+<context>http</context>
+<context>server</context>
+<appeared-in>1.27.1</appeared-in>
+
+<para>
+Limits the maximum allowed number of client request header fields.
+If the limit is exceeded, the
+<http-status code="400" text="Bad Request"/>
+error is returned to the client.
+</para>
+
+<para>
+If the directive is specified on the <link id="server"/> level,
+the value from the default server can be used.
+Details are provided in the
+“<link doc="server_names.xml" id="virtual_server_selection">Virtual
+server selection</link>” section.
+</para>
+
+</directive>
+
+
 <directive name="max_ranges">
 <syntax><value>number</value></syntax>
 <default/>
diff -r 796fbd13ae36 -r 3b5594157fab xml/en/docs/http/server_names.xml
--- a/xml/en/docs/http/server_names.xml	Tue May 14 17:59:30 2024 +0300
+++ b/xml/en/docs/http/server_names.xml	Fri May 24 01:16:29 2024 +0300
@@ -8,7 +8,7 @@
 <article name="Server names"
          link="/en/docs/http/server_names.html"
          lang="en"
-         rev="4"
+         rev="5"
          author="Igor Sysoev"
          editor="Brian Mercer">
 
@@ -404,6 +404,7 @@
 in case of the
 <link doc="ngx_http_core_module.xml" id="ignore_invalid_headers"/>,
 <link doc="ngx_http_core_module.xml" id="large_client_header_buffers"/>,
+<link doc="ngx_http_core_module.xml" id="max_headers"/>,
 and
 <link doc="ngx_http_core_module.xml" id="underscores_in_headers"/> directives
 involved in processing request header fields,
diff -r 796fbd13ae36 -r 3b5594157fab xml/ru/docs/http/ngx_http_core_module.xml
--- a/xml/ru/docs/http/ngx_http_core_module.xml	Tue May 14 17:59:30 2024 +0300
+++ b/xml/ru/docs/http/ngx_http_core_module.xml	Fri May 24 01:16:29 2024 +0300
@@ -10,7 +10,7 @@
 <module name="Модуль ngx_http_core_module"
         link="/ru/docs/http/ngx_http_core_module.html"
         lang="ru"
-        rev="107">
+        rev="108">
 
 <section id="directives" name="Директивы">
 
@@ -1774,6 +1774,30 @@
 </directive>
 
 
+<directive name="max_headers">
+<syntax><value>число</value></syntax>
+<default>1000</default>
+<context>http</context>
+<context>server</context>
+<appeared-in>1.27.1</appeared-in>
+
+<para>
+Ограничивает максимальное допустимое число полей заголовка запроса клиента.
+При превышении указанного ограничения клиенту возвращается ошибка
+<http-status code="400" text="Bad Request"/>.
+</para>
+
+<para>
+Если директива указана на уровне <link id="server"/>,
+то может использоваться значение из сервера по умолчанию.
+Подробнее см. в разделе
+“<link doc="server_names.xml" id="virtual_server_selection">Выбор
+виртуального сервера</link>”.
+</para>
+
+</directive>
+
+
 <directive name="max_ranges">
 <syntax><value>число</value></syntax>
 <default/>
diff -r 796fbd13ae36 -r 3b5594157fab xml/ru/docs/http/server_names.xml
--- a/xml/ru/docs/http/server_names.xml	Tue May 14 17:59:30 2024 +0300
+++ b/xml/ru/docs/http/server_names.xml	Fri May 24 01:16:29 2024 +0300
@@ -8,7 +8,7 @@
 <article name="Имена сервера"
          link="/ru/docs/http/server_names.html"
          lang="ru"
-         rev="4"
+         rev="5"
          author="Игорь Сысоев"
          editor="Brian Mercer">
 
@@ -408,7 +408,8 @@
 <listitem>
 в случае использования директив
 <link doc="ngx_http_core_module.xml" id="ignore_invalid_headers"/>,
-<link doc="ngx_http_core_module.xml" id="large_client_header_buffers"/>
+<link doc="ngx_http_core_module.xml" id="large_client_header_buffers"/>,
+<link doc="ngx_http_core_module.xml" id="max_headers"/>
 и
 <link doc="ngx_http_core_module.xml" id="underscores_in_headers"/>,
 которые участвуют в обработке полей заголовка запроса,

